@@ -3,8 +3,8 @@
 #' GenerateLookup() called in CalEpletMHCII()
 #' @param lkup_in data table
 #' @param locus_in string
-#' CalRiskScr() called in CalEpletMHCII()
-#' @param dat_scr dataframe
+#' CalRiskScore() calculate DR DQ risk score, it's called in CalEpletMHCII()
+#' @param dat_in dataframe
 #' FuncForCompHaplo() called in ImputeHaplo()
 #' @param tbl_raw data frame
 #' @param tbl_in data frame
@@ -19,56 +19,93 @@ NULL
 #' @rdname utils
 GenerateLookup <- function(lkup_in, locus_in){
   dat_out <- lkup_in %>%
-              filter(locus %in% locus_in) %>%
-              mutate(index = as.numeric(sub(".*\\_", "", variable)),
-                     type = sub("\\_.*", "", variable)) %>%
-              select(index, type, value) %>%
-              dplyr::rename(eplet = value) %>%
-              filter(eplet != "") %>%
-              distinct()
+    filter(locus %in% locus_in) %>%
+    mutate(index = as.numeric(sub(".*\\_", "", variable)),
+           type = sub("\\_.*", "", variable)) %>%
+    select(index, type, value) %>%
+    dplyr::rename(eplet = value) %>%
+    filter(eplet != "") %>%
+    distinct()
 
   return(dat_out)
 }
 
 #' @rdname utils
-CalRiskScr <- function(dat_scr) {
-  risk_scr <- dat_scr %>%
-    filter(!(mm_eplets %in% c("Not Found", "", " "))) %>%
+CalRiskScore <- function(dat_in) {
+  #* start of old dq score: dq = sum(max(dqa1, dqb1), max(dqa2, dqb2)) *#
+  # pre_ck <- dat_in %>%
+  #   mutate(hla = toupper(hla)) %>%
+  #   filter(!(mm_eplets %in% c("Not Found"))) %>%
+  #   filter(str_detect(hla, "DRB|DQ")) %>%
+  #   mutate(hla = gsub("\\*.*", "", hla),
+  #          grp = ifelse(str_detect(hla, "DRB"), "DR",
+  #                       ifelse(hla %in% c("DQA1", "DQB1") & haplotype_id %in% c("1"), "DQ1",
+  #                              ifelse(hla %in% c("DQA1", "DQB1") & haplotype_id %in% c("2"), "DQ2", hla)))) %>%
+  #   filter(grp %in% c("DR", "DQ1", "DQ2"))
+  #
+  # if(dim(pre_ck)[1] == 0 | !all(c("DR", "DQ1", "DQ2") %in% unique(pre_ck$grp))) {
+  #   #stop("DR DQ risk score calculation requires eplet mismatch info on both DR DQ alleles. Please check your data.")
+  #   warning("DR and DQ risk score calculation require input of both DR and DQ. No score is calculated at this time.")
+  #   risk_scr <- data.frame(pair_id = NA, DQ = NA, DR = NA, risk = NA)
+  # } else{
+  #   risk_scr <- pre_ck %>%
+  #     group_by(grp) %>%
+  #     summarise(max1 = suppressWarnings(max(mm_cnt, na.rm=TRUE)),
+  #               sum1 = sum(mm_cnt, na.rm=TRUE)) %>%
+  #     ungroup()  %>%
+  #     mutate(max1 = ifelse(grp %in% c("DQ1", "DQ2"), sum1, max1)) %>%
+  #     select(-sum1) %>%
+  #     mutate(locus = ifelse(grp %in% c("DR"), "DR", "DQ")) %>%
+  #     group_by(locus) %>%
+  #     summarise(score = suppressWarnings(max(max1, na.rm=TRUE))) %>%
+  #     ungroup() %>%
+  #     rownames_to_column %>%
+  #     gather(var, value, -rowname) %>%
+  #     spread(rowname, value) %>%
+  #     janitor::row_to_names(1) %>%
+  #     mutate(DQ = as.numeric(DQ),
+  #            DR = as.numeric(DR),
+  #            risk = ifelse(between(DQ, 15, 31), "high",
+  #                          ifelse((DR >= 7 & DQ <= 14) | (DR < 7 & between(DQ, 9, 15)), "interm",
+  #                                 ifelse(DR < 7 & DQ < 9, "low", "out of bound"))))
+  #}
+ #* end of old dq score *#
+
+  #* start of new dq score: dq = sum(max(dqa 1, 2), max(dqb 1, 2)) *#
+  pre_ck <- dat_in %>%
+    mutate(hla = toupper(hla)) %>%
+    filter(!(mm_eplets %in% c("Not Found"))) %>%
+    filter(str_detect(hla, "DRB|DQ")) %>%
     mutate(hla = gsub("\\*.*", "", hla),
            grp = ifelse(str_detect(hla, "DRB"), "DR",
-                        ifelse(hla %in% c("DQA1", "DQB1") & haplotype_id %in% c("1"), "DQ1",
-                               ifelse(hla %in% c("DQA1", "DQB1") & haplotype_id %in% c("2"), "DQ2", hla)))) %>%
-    filter(grp %in% c("DR", "DQ1", "DQ2") & mm_cnt > 0 ) %>%
-    group_by(grp) %>%
-    summarise(max1 = suppressWarnings(max(mm_cnt, na.rm=TRUE)),
-              sum1 = sum(mm_cnt, na.rm=TRUE)) %>%
-    ungroup()  %>%
-    mutate(max1 = ifelse(grp %in% c("DQ1", "DQ2"), sum1, max1)) %>%
-    select(-sum1) %>%
-    mutate(locus = ifelse(grp %in% c("DR"), "DR", "DQ")) %>%
-    group_by(locus) %>%
-    summarise(score = suppressWarnings(max(max1, na.rm=TRUE))) %>%
-    ungroup() %>%
-    as.data.frame() %>%
-    rownames_to_column %>%
-    gather(var, value, -rowname) %>%
-    spread(rowname, value) %>%
-    janitor::row_to_names(1) %>%
-    as.data.frame()
+                        ifelse(hla %in% c("DQA1", "DQA2"), "DQA",
+                               ifelse(hla %in% c("DQB1", "DQB2"), "DQB", hla)))) %>%
+    filter(grp %in% c("DR", "DQA", "DQB"))
 
-  if("DQ" %in% names(risk_scr) & "DR" %in% names(risk_scr)){
-    risk_scr <- risk_scr %>%
-      # change data type to numeric for risk calculation
-      mutate(DQ = as.numeric(DQ),
-             DR = as.numeric(DR)) %>%
-      mutate(risk = ifelse(between(DQ, 15, 31), "high",
-                           ifelse((DR >= 7 & DQ <= 14) | (DR < 7 & between(DQ, 9, 15)), "interm",
-                                  ifelse(DR < 7 & DQ < 9, "low", "out of bound"))))
-  } else {
+  if(dim(pre_ck)[1] == 0 | !all(c("DR", "DQA", "DQB") %in% unique(pre_ck$grp))) {
+    #stop("DR DQ risk score calculation requires eplet mismatch info on both DR DQ alleles. Please check your data.")
     warning("DR and DQ risk score calculation require input of both DR and DQ. No score is calculated at this time.")
     risk_scr <- data.frame(pair_id = NA, DQ = NA, DR = NA, risk = NA)
+  } else{
+    risk_scr <- pre_ck %>%
+      group_by(grp) %>%
+      summarise(scr = suppressWarnings(max(mm_cnt, na.rm=TRUE)) ) %>%
+      ungroup()  %>%
+      mutate(locus = ifelse(grp %in% c("DR"), "DR", "DQ")) %>%
+      group_by(locus) %>%
+      summarise(score = suppressWarnings(sum(scr, na.rm=TRUE))) %>%
+      ungroup() %>%
+      as.data.frame() %>%
+      rownames_to_column %>%
+      gather(var, value, -rowname) %>%
+      spread(rowname, value) %>%
+      janitor::row_to_names(1) %>%
+      mutate(DQ = as.numeric(DQ),
+             DR = as.numeric(DR),
+             risk = ifelse(between(DQ, 15, 31), "high",
+                           ifelse((DR >= 7 & DQ <= 14) | (DR < 7 & between(DQ, 9, 15)), "interm",
+                                  ifelse(DR < 7 & DQ < 9, "low", "out of bound"))))
   }
-
   return(risk_scr)
 }
 
